@@ -55,26 +55,15 @@ def test_openapi_schema(client: TestClient):
                                     "title": "Item",
                                     "examples": [
                                         {
-                                            "summary": "A normal example",
-                                            "description": "A **normal** item works correctly.",
-                                            "value": {
-                                                "name": "Foo",
-                                                "description": "A very nice Item",
-                                                "price": 35.4,
-                                                "tax": 3.2,
-                                            },
+                                            "name": "Foo",
+                                            "description": "A very nice Item",
+                                            "price": 35.4,
+                                            "tax": 3.2,
                                         },
+                                        {"name": "Bar", "price": "35.4"},
                                         {
-                                            "summary": "An example with converted data",
-                                            "description": "FastAPI can convert price `strings` to actual `numbers` automatically",
-                                            "value": {"name": "Bar", "price": "35.4"},
-                                        },
-                                        {
-                                            "summary": "Invalid data is rejected with an error",
-                                            "value": {
-                                                "name": "Baz",
-                                                "price": "thirty five point four",
-                                            },
+                                            "name": "Baz",
+                                            "price": "thirty five point four",
                                         },
                                     ],
                                 }
